#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh - mail-panda installation
#
# Copyright (c) 2020-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation   :  2020-05-25 root
# Last update:  $Id: install.sh 79345 2020-07-11 18:56:19Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# set package name
module_name='mail-panda'

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/${module_name}-$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

myecho --pack ${module_name} --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# add antispam entry
/var/install/bin/add-menu --menu "setup.services.mail.modules.menu" \
                                 "setup.services.mail.modules.${module_name}.menu" "Panda-IMAP administration"

silent=''
# install/update package configuration file
if called_from_install --pack "${module_name}"
then
    silent='--quiet'
fi

# update mail modules menu
/var/install/config.d/mail.sh ${silent} --updatemodulesmenu

update=false
if install_config ${silent} ${module_name}
then
    update=true
fi

# configuration
myecho --pack ${module_name} "creating ${module_name} configuration ..."

# updated installation
if [ -f /var/install/config.d/${module_name}.sh ]
then
    /var/install/config.d/${module_name}.sh
fi

if [ -f /etc/init.d/${module_name} ]
then
    /etc/init.d/${module_name} start
fi

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
exit 0
