#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/preinstall.sh - panda pre-installation
#
# Copyright (c) 2020-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation   :  2020-05-25 root
# Last update:  $Id: preinstall.sh 77626 2020-05-25 17:44:54Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
module_name='mail-panda'

configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
deinstallfile=/var/install/deinstall/${module_name}
packagefile=/var/install/packages/${module_name}

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

myecho --pack ${module_name} --info "running preinstall.sh ..."

if [ -f /etc/init.d/${module_name} ]
then
    myecho --pack ${module_name} "stopping running processes ..."
    /etc/init.d/${module_name} stop
fi

# deinstall old software
myecho --pack ${module_name} "deinstalling previously installed software ..."

# backup existing file
if [ -f ${configfile} ]
then
    # move old files to backup directory and create backup
    /var/install/bin/backup-file --quiet ${module_name}

    myecho --pack ${module_name} "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}
fi

if [ -f /var/install/deinstall/${module_name} ]
then
    /usr/bin/eisman uninstall --update --auto --quiet ${module_name}
fi

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
exit 0
