#!/bin/sh
#----------------------------------------------------------------------------------------
# /var/install/config.d/mail-panda.sh - configuration script for mail-panda server
#
# Copyright (c) 2001-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2002-04-28 fm
# Last Update:  $Id: mail-panda.sh 79036 2020-07-01 20:28:23Z jed $
#
# Usage: mail.sh [--noconfirm][--quiet] [command]
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/$(basename $0)-config-$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

pgmname=`basename $0`
module_name=`basename -s .sh ${pgmname}`

mailpanda_file=/etc/config.d/${module_name}

### other parameters ###
if [ "`/usr/bin/eisman check ${module_name}`" = 'installed' ]
then
    mail_version="`/usr/bin/eisman query --installed --fields=version --no-tty ${module_name} | sed -e '/^version/!d' -e 's/^version *//' | tail -n1`"
else
    mail_version='unknown'
fi

### load configuration ###
. ${mailpanda_file}
chmod 0600 ${mailpanda_file}

#========================================================================================
# Main
#========================================================================================

noconfirm=false
force_quiet_run=false
if [ $# -gt 0 ]
then
    # read parameter(s)
    while [ $# -gt 0 ]
    do
        case $1 in
            --noconfirm )
                noconfirm=true
                shift
                ;;
            --quiet )
                force_quiet_run=true
                shift
                ;;
            * )
                cmd="$1"
                break
                ;;
        esac
    done
fi

case ${cmd} in
    * )
        # generate all configuration files
        myecho --pack ${module_name}
        myecho --pack ${module_name} "version: ${mail_version}"

        myecho --pack ${module_name} "finished."
        ;;
esac

#========================================================================================
# End
#========================================================================================
exit 0
